@@ -8,14 +8,17 @@ from paypalrestsdk.version    import __version__
 class Api:
 
   # User-Agent for HTTP request
-  user_agent = "PayPalSDK/rest-sdk-python %s(httplib2 %s; python %s)"%(__version__, httplib2.__version__, platform.python_version())
+  library_details = "httplib2 %s; python %s"%(httplib2.__version__, platform.python_version())
+  user_agent = "PayPalSDK/rest-sdk-python %s (%s)"%(__version__, library_details)
 
   # Create API object
   # == Example
   #   import paypalrestsdk
-  #   api = paypalrestsdk.Api( mode="sandbox", 
+  #   api = paypalrestsdk.Api( mode="sandbox",
   #          client_id='CLIENT_ID', client_secret='CLIENT_SECRET', ssl_options={} )
-  def __init__(self, **args):
+  def __init__(self, options = {}, **args):
+    args = util.merge_dict(options, args)
+
     self.mode           = args.get("mode", "sandbox")
     self.endpoint       = args.get("endpoint", self.default_endpoint())
     self.token_endpoint = args.get("token_endpoint", self.endpoint)
@@ -28,6 +31,8 @@ class Api:
     if args.get("token"):
       self.token_hash     = { "access_token": args.get("token"), "token_type": "Bearer" }
 
+    self.options = args
+
   # Default endpoint
   def default_endpoint(self):
     if self.mode == "live" :
@@ -54,7 +59,7 @@ class Api:
   # Validate expires_in
   def validate_token_hash(self):
     if self.token_request_at and self.token_hash and self.token_hash.get("expires_in") != None :
-      duration = (datetime.datetime.now() - self.token_request_at).total_seconds() 
+      duration = (datetime.datetime.now() - self.token_request_at).total_seconds()
       if duration > self.token_hash.get("expires_in"):
         self.token_hash = None
 
@@ -171,7 +176,9 @@ def default():
   return __api__
 
 # Create new default api object with given configuration
-def set_config(**config):
+def set_config(options = {}, **config):
   global __api__
-  __api__ = Api(**config)
+  __api__ = Api(options, **config)
   return __api__
+
+configure = set_config
